##  Invite the Core Team
The core team is a group of key stakeholders in your organization working with SAP LeanIX. Identify the key stakeholders who will have administrator access to your workspace, then invite them.
Setting up single sign-on (SSO) is recommended for streamlined user and access management. Before configuring SSO, manually invite the core team and start setting up your workspace with them.
To invite users to your workspace manually, follow these steps:
  1. On the user profile menu, select Invite User.
  2. In the overlay that appears, enter users' email addresses and select a role.
  3. Choose Invite.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioef2281d94cb84c80b679905ae368739d_LowRes.png)
Inviting Users from a Workspace


After confirming the invitation and setting credentials, users get access to the workspace.
